diff decoders/flac.c @ 221:c9772a9f5271

Initial implementation or stubs for rewind method. Other cleanups.
author Ryan C. Gordon <icculus@icculus.org>
date Thu, 17 Jan 2002 20:53:53 +0000
parents 47cc2de2ae36
children d3dc34315ac7
line wrap: on
line diff
--- a/decoders/flac.c	Thu Jan 17 20:53:03 2002 +0000
+++ b/decoders/flac.c	Thu Jan 17 20:53:53 2002 +0000
@@ -53,6 +53,7 @@
 static int FLAC_open(Sound_Sample *sample, const char *ext);
 static void FLAC_close(Sound_Sample *sample);
 static Uint32 FLAC_read(Sound_Sample *sample);
+static int FLAC_rewind(Sound_Sample *sample);
 
 static const char *extensions_flac[] = { "FLAC", "FLA", NULL };
 
@@ -65,11 +66,12 @@
         "http://flac.sourceforge.net/"
     },
 
-    FLAC_init,       /* init() method       */
-    FLAC_quit,       /* quit() method       */
-    FLAC_open,       /* open() method       */
-    FLAC_close,      /* close() method       */
-    FLAC_read        /* read() method       */
+    FLAC_init,       /*   init() method */
+    FLAC_quit,       /*   quit() method */
+    FLAC_open,       /*   open() method */
+    FLAC_close,      /*  close() method */
+    FLAC_read,       /*   read() method */
+    FLAC_rewind      /* rewind() method */
 };
 
     /* This is what we store in our internal->decoder_private field. */
@@ -360,6 +362,15 @@
     return(f->frame_size);
 } /* FLAC_read */
 
+
+static int FLAC_rewind(Sound_Sample *sample)
+{
+    /* !!! FIXME. */
+    SNDDBG(("FLAC_rewind(): Write me!\n"));
+    assert(0);
+    return(0);
+} /* FLAC_rewind */
+
 #endif /* SOUND_SUPPORTS_FLAC */